<?php
session_start();
if (!isset($_SESSION['admin_logged_in'])) {
    header('Location: login.php');
    exit;
}

$room_id = $_GET['room_id'] ?? '';
if (!$room_id) {
    header('Location: index.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Chat</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            background: #f4f4f4;
        }
        .chat-container {
            max-width: 800px;
            margin: 0 auto;
            background: white;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            overflow: hidden;
        }
        .chat-header {
            background: #007bff;
            color: white;
            padding: 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .back-button {
            background: transparent;
            border: 1px solid white;
            color: white;
            padding: 8px 16px;
            border-radius: 4px;
            cursor: pointer;
        }
        .chat-messages {
            height: 500px;
            overflow-y: auto;
            padding: 20px;
            background: #f8f9fa;
        }
        .message {
            margin: 10px 0;
            padding: 10px;
            border-radius: 8px;
            max-width: 70%;
            word-wrap: break-word;
        }
        .user-message {
            background: #e9ecef;
            margin-right: auto;
        }
        .admin-message {
            background: #007bff;
            color: white;
            margin-left: auto;
        }
        .message-time {
            font-size: 12px;
            margin-top: 5px;
            opacity: 0.8;
        }
        .chat-input {
            display: flex;
            padding: 15px;
            background: #fff;
            border-top: 1px solid #dee2e6;
            gap: 10px;
        }
        .chat-input input {
            flex: 1;
            padding: 10px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            font-size: 16px;
        }
        .chat-input button {
            padding: 10px 20px;
            background: #007bff;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        .debug-info {
            margin-top: 10px;
            padding: 10px;
            background: #fff;
            border-radius: 4px;
            font-size: 12px;
        }
    </style>
</head>
<body>
    <div class="chat-container">
        <div class="chat-header">
            <button class="back-button" onclick="window.location.href='index.php'">← Geri Dön</button>
            <div id="user-info">Kullanıcı bilgileri yükleniyor...</div>
        </div>
        <div id="messages" class="chat-messages"></div>
        <div class="chat-input">
            <input type="text" id="messageInput" placeholder="Mesajınızı yazın..." autofocus>
            <button onclick="sendMessage()">Gönder</button>
        </div>
    </div>
    <div id="debug-info" class="debug-info"></div>

    <script>
    const roomId = '<?php echo $room_id; ?>';
    const API_URL = 'https://gescooters-invest.com/api/chat.php';

    function debugLog(message) {
        console.log(message);
        const debugDiv = document.getElementById('debug-info');
        debugDiv.innerHTML += `<div>${new Date().toLocaleTimeString()}: ${message}</div>`;
    }

    function loadUserInfo() {
        fetch(`${API_URL}?action=get_chat_info&room_id=${roomId}`)
        .then(response => response.json())
        .then(data => {
            if (data.success && data.chat) {
                document.getElementById('user-info').innerHTML = `
                    <strong>${data.chat.username}</strong><br>
                    <small>${data.chat.email}</small>
                `;
            }
        });
    }

    function loadMessages() {
        fetch(`${API_URL}?action=get_messages&room_id=${roomId}&t=${Date.now()}`)
        .then(response => response.json())
        .then(data => {
            debugLog('Messages response: ' + JSON.stringify(data));
            if (data.success && data.messages) {
                const messagesDiv = document.getElementById('messages');
                messagesDiv.innerHTML = data.messages.map(msg => `
                    <div class="message ${msg.sender_type}-message">
                        ${msg.sender_type === 'user' ? '<strong>Kullanıcı:</strong> ' : ''}
                        ${msg.message}
                        <div class="message-time">${new Date(msg.created_at).toLocaleTimeString()}</div>
                    </div>
                `).join('');
                messagesDiv.scrollTop = messagesDiv.scrollHeight;
            }
        })
        .catch(error => {
            debugLog('Error loading messages: ' + error.message);
        });
    }

    function sendMessage() {
        const messageInput = document.getElementById('messageInput');
        const message = messageInput.value.trim();
        
        if (!message) return;

        const formData = new FormData();
        formData.append('action', 'send_message');
        formData.append('room_id', roomId);
        formData.append('message', message);
        formData.append('sender_type', 'admin');

        fetch(API_URL, {
            method: 'POST',
            body: formData
        })
        .then(response => response.json())
        .then(data => {
            debugLog('Send message response: ' + JSON.stringify(data));
            if (data.success) {
                messageInput.value = '';
                loadMessages();
            } else {
                throw new Error(data.error || 'Mesaj gönderilemedi');
            }
        })
        .catch(error => {
            debugLog('Error sending message: ' + error.message);
            alert('Mesaj gönderilemedi: ' + error.message);
        });
    }

    // Enter tuşu ile mesaj gönderme
    document.getElementById('messageInput').addEventListener('keypress', function(e) {
        if (e.key === 'Enter' && !e.shiftKey) {
            e.preventDefault();
            sendMessage();
        }
    });

    // Sayfa yüklendiğinde
    loadUserInfo();
    loadMessages();

    // Her 1 saniyede bir mesajları güncelle
    setInterval(loadMessages, 1000);
    </script>
</body>
</html>