<?php
session_start();
if(!isset($_SESSION['admin_logged_in'])) {
    header('Location: login.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel</title>
    <style>
        body { 
            font-family: Arial, sans-serif; 
            margin: 20px; 
            background: #f4f4f4;
        }
        .container {
            max-width: 1200px;
            margin: 0 auto;
        }
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            background: white;
            padding: 15px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .chat-section {
            background: white;
            padding: 20px;
            margin-bottom: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .chat-item {
            border: 1px solid #ddd;
            padding: 15px;
            margin-bottom: 10px;
            border-radius: 4px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            background: #fff;
        }
        .chat-info {
            flex: 1;
        }
        .chat-actions {
            margin-left: 15px;
        }
        button {
            padding: 8px 16px;
            background: #007bff;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        button:hover {
            background: #0056b3;
        }
        .logout {
            background: #dc3545;
        }
        .logout:hover {
            background: #c82333;
        }
        .empty-message {
            text-align: center;
            padding: 20px;
            color: #666;
            font-style: italic;
        }
        .debug-info {
            background: #f8f9fa;
            padding: 10px;
            margin-top: 20px;
            border-radius: 4px;
            font-family: monospace;
            font-size: 12px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>Canlı Destek Admin Paneli</h1>
            <a href="logout.php"><button class="logout">Çıkış Yap</button></a>
        </div>

        <div class="chat-section">
            <h2>Bekleyen Görüşmeler</h2>
            <div id="waiting-chats">Yükleniyor...</div>
        </div>

        <div class="chat-section">
            <h2>Aktif Görüşmeler</h2>
            <div id="active-chats">Yükleniyor...</div>
        </div>

        <div id="debug-info" class="debug-info"></div>
    </div>

    <script>
    const API_URL = 'https://gescooters-invest.com/api/chat.php';
    let lastUpdate = 0;

    function debugLog(message) {
        console.log(message);
        document.getElementById('debug-info').innerHTML += `<div>${new Date().toLocaleTimeString()}: ${message}</div>`;
    }

    function loadChats() {
        debugLog('Sohbetler yükleniyor...');

        // Bekleyen görüşmeleri yükle
        fetch(`${API_URL}?action=get_waiting_chats&t=${Date.now()}`)
        .then(response => response.json())
        .then(data => {
            debugLog('Bekleyen görüşmeler yanıtı: ' + JSON.stringify(data));
            
            const waitingChats = document.getElementById('waiting-chats');
            if(data.success && data.chats && data.chats.length > 0) {
                waitingChats.innerHTML = data.chats.map(chat => `
                    <div class="chat-item">
                        <div class="chat-info">
                            <strong>${chat.username}</strong><br>
                            ${chat.email}<br>
                            <small>Oluşturulma: ${new Date(chat.created_at).toLocaleString()}</small>
                        </div>
                        <div class="chat-actions">
                            <button onclick="startChat('${chat.room_id}')">Görüşmeyi Başlat</button>
                        </div>
                    </div>
                `).join('');
            } else {
                waitingChats.innerHTML = '<div class="empty-message">Bekleyen görüşme bulunmuyor</div>';
            }
        })
        .catch(error => {
            debugLog('Hata: ' + error.message);
            document.getElementById('waiting-chats').innerHTML = 
                '<div class="empty-message">Görüşmeler yüklenirken bir hata oluştu</div>';
        });

        // Aktif görüşmeleri yükle
        fetch(`${API_URL}?action=get_active_chats&t=${Date.now()}`)
        .then(response => response.json())
        .then(data => {
            debugLog('Aktif görüşmeler yanıtı: ' + JSON.stringify(data));
            
            const activeChats = document.getElementById('active-chats');
            if(data.success && data.chats && data.chats.length > 0) {
                activeChats.innerHTML = data.chats.map(chat => `
                    <div class="chat-item">
                        <div class="chat-info">
                            <strong>${chat.username}</strong><br>
                            ${chat.email}<br>
                            <small>Başlangıç: ${new Date(chat.created_at).toLocaleString()}</small>
                        </div>
                        <div class="chat-actions">
                            <button onclick="openChat('${chat.room_id}')">Görüşmeye Devam Et</button>
                        </div>
                    </div>
                `).join('');
            } else {
                activeChats.innerHTML = '<div class="empty-message">Aktif görüşme bulunmuyor</div>';
            }
        })
        .catch(error => {
            debugLog('Hata: ' + error.message);
            document.getElementById('active-chats').innerHTML = 
                '<div class="empty-message">Görüşmeler yüklenirken bir hata oluştu</div>';
        });

        lastUpdate = Date.now();
    }

    function startChat(roomId) {
        debugLog('Görüşme başlatılıyor: ' + roomId);
        
        fetch(API_URL, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: `action=update_status&room_id=${roomId}&status=active`
        })
        .then(response => response.json())
        .then(data => {
            debugLog('Görüşme başlatma yanıtı: ' + JSON.stringify(data));
            if(data.success) {
                window.location.href = `chat.php?room_id=${roomId}`;
            } else {
                alert('Görüşme başlatılırken bir hata oluştu');
            }
        })
        .catch(error => {
            debugLog('Hata: ' + error.message);
            alert('Görüşme başlatılırken bir hata oluştu');
        });
    }

    function openChat(roomId) {
        window.location.href = `chat.php?room_id=${roomId}`;
    }

    // Sayfa yüklendiğinde ve her 5 saniyede bir güncelle
    loadChats();
    setInterval(() => {
        // Son güncellemeden 5 saniye geçtiyse güncelle
        if (Date.now() - lastUpdate >= 5000) {
            loadChats();
        }
    }, 5000);
    </script>
</body>
</html>