<?php
// CORS ve header ayarları
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST');
header('Access-Control-Allow-Headers: Content-Type');
header('Content-Type: application/json; charset=utf-8');

// Hata raporlama
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);
ini_set('error_log', dirname(__FILE__) . '/debug.log');

require_once '../config.php';

// Gelen istekleri logla
error_log("API Request: " . print_r($_REQUEST, true));
error_log("Raw POST Data: " . file_get_contents("php://input"));

// OPTIONS request için kontrol
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Yeni sohbet başlatma
if (isset($_POST['action']) && $_POST['action'] == 'new_chat') {
    try {
        // Gelen verileri kontrol et
        if (empty($_POST['room_id']) || empty($_POST['username']) || empty($_POST['email']) || empty($_POST['message'])) {
            throw new Exception('Eksik parametreler');
        }

        $room_id = $_POST['room_id'];
        $username = $_POST['username'];
        $email = $_POST['email'];
        $message = $_POST['message'];

        error_log("New Chat Attempt - Room: $room_id, User: $username, Email: $email");

        // Transaction başlat
        $db->beginTransaction();

        // Sohbet odasını oluştur
        $stmt = $db->prepare("INSERT INTO chat_rooms (room_id, username, email, status, created_at) VALUES (?, ?, ?, 'waiting', NOW())");
        $result1 = $stmt->execute([$room_id, $username, $email]);

        // İlk mesajı ekle
        $stmt = $db->prepare("INSERT INTO messages (room_id, sender_type, message, created_at) VALUES (?, 'user', ?, NOW())");
        $result2 = $stmt->execute([$room_id, $message]);

        if ($result1 && $result2) {
            $db->commit();
            echo json_encode(['success' => true]);
        } else {
            throw new Exception('Veritabanı işlemi başarısız');
        }

    } catch (Exception $e) {
        $db->rollBack();
        error_log("New Chat Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Sohbet durumunu kontrol et
if (isset($_GET['action']) && $_GET['action'] == 'check_status') {
    try {
        if (empty($_GET['room_id'])) {
            throw new Exception('Room ID gerekli');
        }

        $room_id = $_GET['room_id'];
        $stmt = $db->prepare("SELECT status FROM chat_rooms WHERE room_id = ?");
        $stmt->execute([$room_id]);
        $status = $stmt->fetchColumn();

        if ($status === false) {
            throw new Exception('Sohbet odası bulunamadı');
        }

        echo json_encode(['success' => true, 'status' => $status]);
    } catch (Exception $e) {
        error_log("Check Status Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Mesajları getir
if (isset($_GET['action']) && $_GET['action'] == 'get_messages') {
    try {
        if (empty($_GET['room_id'])) {
            throw new Exception('Room ID gerekli');
        }

        $room_id = $_GET['room_id'];
        $stmt = $db->prepare("SELECT * FROM messages WHERE room_id = ? ORDER BY created_at ASC");
        $stmt->execute([$room_id]);
        $messages = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'messages' => $messages]);
    } catch (Exception $e) {
        error_log("Get Messages Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Mesaj gönder
if (isset($_POST['action']) && $_POST['action'] == 'send_message') {
    try {
        if (empty($_POST['room_id']) || empty($_POST['message']) || empty($_POST['sender_type'])) {
            throw new Exception('Eksik parametreler');
        }

        $room_id = $_POST['room_id'];
        $message = $_POST['message'];
        $sender_type = $_POST['sender_type'];

        // Sohbet odasının durumunu kontrol et
        $stmt = $db->prepare("SELECT status FROM chat_rooms WHERE room_id = ?");
        $stmt->execute([$room_id]);
        $status = $stmt->fetchColumn();

        if ($status === false) {
            throw new Exception('Geçersiz sohbet odası');
        }

        if ($status !== 'active' && $sender_type === 'admin') {
            throw new Exception('Sohbet henüz aktif değil');
        }

        $stmt = $db->prepare("INSERT INTO messages (room_id, sender_type, message, created_at) VALUES (?, ?, ?, NOW())");
        $result = $stmt->execute([$room_id, $sender_type, $message]);

        if ($result) {
            echo json_encode(['success' => true]);
        } else {
            throw new Exception('Mesaj gönderilemedi');
        }

    } catch (Exception $e) {
        error_log("Send Message Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Bekleyen sohbetleri getir
if (isset($_GET['action']) && $_GET['action'] == 'get_waiting_chats') {
    try {
        $stmt = $db->prepare("SELECT * FROM chat_rooms WHERE status = 'waiting' ORDER BY created_at ASC");
        $stmt->execute();
        $chats = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'chats' => $chats]);
    } catch (Exception $e) {
        error_log("Get Waiting Chats Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Aktif sohbetleri getir
if (isset($_GET['action']) && $_GET['action'] == 'get_active_chats') {
    try {
        $stmt = $db->prepare("SELECT * FROM chat_rooms WHERE status = 'active' ORDER BY created_at DESC");
        $stmt->execute();
        $chats = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'chats' => $chats]);
    } catch (Exception $e) {
        error_log("Get Active Chats Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Sohbet durumunu güncelle
if (isset($_POST['action']) && $_POST['action'] == 'update_status') {
    try {
        if (empty($_POST['room_id']) || empty($_POST['status'])) {
            throw new Exception('Eksik parametreler');
        }

        $room_id = $_POST['room_id'];
        $status = $_POST['status'];

        if (!in_array($status, ['waiting', 'active', 'closed'])) {
            throw new Exception('Geçersiz durum');
        }

        $stmt = $db->prepare("UPDATE chat_rooms SET status = ? WHERE room_id = ?");
        $result = $stmt->execute([$status, $room_id]);

        if ($result) {
            // Sistem mesajı ekle
            if ($status == 'active') {
                $stmt = $db->prepare("INSERT INTO messages (room_id, sender_type, message, created_at) VALUES (?, 'system', 'Temsilci görüşmeye katıldı.', NOW())");
                $stmt->execute([$room_id]);
            }
            echo json_encode(['success' => true]);
        } else {
            throw new Exception('Durum güncellenemedi');
        }

    } catch (Exception $e) {
        error_log("Update Status Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Sohbet bilgilerini getir
if (isset($_GET['action']) && $_GET['action'] == 'get_chat_info') {
    try {
        if (empty($_GET['room_id'])) {
            throw new Exception('Room ID gerekli');
        }

        $room_id = $_GET['room_id'];
        $stmt = $db->prepare("SELECT * FROM chat_rooms WHERE room_id = ?");
        $stmt->execute([$room_id]);
        $chat = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$chat) {
            throw new Exception('Sohbet bulunamadı');
        }

        echo json_encode(['success' => true, 'chat' => $chat]);
    } catch (Exception $e) {
        error_log("Get Chat Info Error: " . $e->getMessage());
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Geçersiz istek
echo json_encode(['success' => false, 'error' => 'Geçersiz istek']);
?>